@@ -156,6 +156,19 @@ public:
    */
   void setLayout(std::unique_ptr<WLayout> layout);
 
+  /*! \brief Sets a layout manager for the container, returning a raw pointer.
+   *
+   * This is implemented as:
+   *
+   * \code
+   * Layout *result = layout.get();
+   * setLayout(std::unique_ptr<WLayout>(std::move(layout)));
+   * return result;
+   * \endcode
+   *
+   * This is a useful shorthand that allows to create a layout and get a raw
+   * pointer to it in one line.
+   */
   template <typename Layout>
     Layout *setLayout(std::unique_ptr<Layout> layout)
 #ifndef WT_TARGET_JAVA
@@ -245,6 +258,19 @@ public:
     addWidget(std::unique_ptr<WWidget>{std::move(w)});
     return result;
   }
+#else // WT_TARGET_JAVA
+  template <typename Widget>
+    Widget *addNew();
+  template <typename Widget, typename Arg1>
+    Widget *addNew(Arg1 arg1);
+  template <typename Widget, typename Arg1, typename Arg2>
+    Widget *addNew(Arg1 arg1, Arg2 arg2);
+  template <typename Widget, typename Arg1, typename Arg2, typename Arg3>
+    Widget *addNew(Arg1 arg1, Arg2 arg2, Arg3 arg3);
+  template <typename Widget, typename Arg1, typename Arg2, typename Arg3, typename Arg4>
+    Widget *addNew(Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4);
+  template <typename Widget, typename Arg1, typename Arg2, typename Arg3, typename Arg4, typename Arg5>
+    Widget *addNew(Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4, Arg5 arg5);
 #endif // WT_TARGET_JAVA
 
   /*! \brief Inserts a child widget in this container, before another
@@ -340,6 +366,8 @@ public:
   }
 #endif // WT_TARGET_JAVA
 
+  using WWidget::removeWidget;
+
   /*! \brief Removes a child widget from this container.
    *
    * If the WContainerWidget owns the given widget (i.e. if it was added
